import pickle

import os
from sklearn.metrics import accuracy_score, classification_report, cohen_kappa_score
from sklearn.utils import compute_sample_weight

from Sensei.present_results import create_confusion_matrix, plot_confusion_matrix

path = "cnn_k_fold_saves/1710-25052019"
categories = ['Healthy', 'Hypopnea', 'OSA']

all_preds = []
all_labels = []

predicted_events_list = []
labeled_events_list = []
predicted_AHI_list = []
labeled_AHI_list = []
accuracies = []
cohens_cappas = []
recalls = []
precisions = []

with open(os.path.join(os.path.dirname(__file__), path), 'rb') as infile:
    data = pickle.load(infile)

data_all_runs = data

for run_data in data_all_runs:
    all_preds.extend(run_data['predictions'])
    all_labels.extend(run_data['labels'])

    predicted_events_list.append(run_data["events"]["predicted_events"])
    labeled_events_list.append(run_data["events"]["labeled_events"])
    predicted_AHI_list.append(run_data["ahi"]["predicted_AHI"])
    labeled_AHI_list.append(run_data["ahi"]["labeled_AHI"])

    print("Cohens: ", run_data['cohens_cappa'])
    print(run_data['raport'])
    print("Accuracy: ", accuracy_score(run_data['labels'], run_data['predictions']))

    print("\n")


print("#"*20, " Summary K-FOLD ", "#"*20)

sample_weights = compute_sample_weight("balanced",
                                      all_preds)

rapport = classification_report(all_labels, all_preds)  # , sample_weight=sample_weights)
conf_mat = create_confusion_matrix(all_labels, all_preds)
cohens_cappa = cohen_kappa_score(all_labels, all_preds)  # , sample_weight=sample_weights)

print("\n Summary all tests... \t\t\t\t")
print("#" * 70, "\n")

print("Sklearn rapport\n", rapport)
print("Cohens kappa\n", cohens_cappa)
print("\nConfusion matrix\n", conf_mat)

plot_confusion_matrix(conf_mat, categories)
