import random

from Sensei import config
from Sensei.data import get_data, dump_data_to_file
from Sensei.data_splitting import train_test_split


def run_pipeline():
    frequency = 5

    random.seed(3)
    seed = 3

    processed_root_bergen = config.processed_root_bergen
    processed_root_colosseum = config.processed_root_colosseum

    root_path_bergen = "processed_data_files_bergen/"
    root_path_colosseum = "processed_data_files_colosseum/"

    somnofy_bergen, _, psg_bergen, _ = train_test_split(
        path=processed_root_bergen, test_size=0,
        seed=seed)

    somnofy_colosseum, _, psg_colosseum, _ = train_test_split(
        path=processed_root_colosseum, test_size=0,
        seed=seed)

    # somnofy_bergen = somnofy_bergen[:5]
    # psg_bergen = psg_bergen[:5]
    # somnofy_colosseum = somnofy_colosseum[:5]
    # psg_colosseum = psg_colosseum[:5]

    # NB: Healthy is always included
    categories = ['Hypopnea', 'Obstructive Apnea']
    features = {
        'vitalsigns': [
            'sensor_state',
            'movement_fast',
            'movement_power_fast',
            'movement_slow',
            'movement_power_slow',
            'signal_quality',
            'distance',
            'respiration_rate',
            'respiration_distance'
        ],
        'derived': [
            'relative_distance'
        ],
        'handcrafted': [
            'rsp_rate',
            'rsp_filtered',
            'rsp_broad'
        ],
        # 'environment': [
        #     # 'iaq',
        #     # 'temperature',
        #     # 'pressure',
        #     # 'humidity'
        # ],
        # 'psg': [
        #    'heart_rate'
        # ],
        # 'psg_raw': [
        #    'rip_thorax'
        # 'rip_abdomen',
        # 'rip_sum'
        # ],

        'spo2_flow_events': [],  # ,
        'spo2': []
    }

    # LOADING BERGENSDATA
    print("Loading data from Bergen... \t\t\t\t\t", end="")

    X_bergen, Y_bergen = get_data(processed_root_bergen, somnofy_bergen, psg_bergen, categories,
                                  features,
                                  frequency=frequency)

    filename = root_path_bergen + "bergen_all_features"
    dump_data_to_file(filename, X_bergen, Y_bergen)
    print("done!")

    # LOADING COLOSSEUMSDATA
    print("Loading data from Colosseum... \t\t\t\t\t", end="")
    X_colosseum, Y_colosseum = get_data(processed_root_colosseum, somnofy_colosseum, psg_colosseum, categories,
                                        features, frequency=frequency)
    filename = root_path_colosseum + "colosseum_all_features"
    dump_data_to_file(filename, X_colosseum, Y_colosseum)

    print("done!")

# run_pipeline()
